@@ -28,6 +28,9 @@ class BaseTestCase(object):
     response: ResponseUtil = None
     context: GlobalAttribute = None
     config: GlobalAttribute = None
+    payment_type: PaymentType = PaymentType
+    risk_level: RiskLevel = RiskLevel
+    is_delayed: IsDelayed = IsDelayed
     # faker方法文档 https://blog.csdn.net/m0_60052979/article/details/126368024
     faker = SingletonFaker(locale=FAKER_LANGUAGE).faker
 
@@ -119,7 +122,8 @@ class BaseTestCase(object):
     def get_customized_kytmock(self, request_id):
         return get_customized_kytmock(self.context.get("env"), request_id)
 
-    def set_customized_kytmock(self, request_id, payment_type: PaymentType, risk_level: RiskLevel, is_delayed: IsDelayed = IsDelayed.NO_DELAY):
+    def set_customized_kytmock(self, request_id, payment_type: PaymentType, risk_level: RiskLevel,
+                               is_delayed: IsDelayed = IsDelayed.NO_DELAY):
         """
           参数:
             env: 环境名称（如
